@@ -7,23 +7,25 @@ from lxml import html
 import re
 import argparse
 from plumbum import cli
+from plumbum import colors
 import pyperclip
 
 from dict_tiny.en_detail.get_detail import get_data, print_basetrans, print_detailtrans
+from dict_tiny import version
 
 APP_DESC = """
 tiny dictionary
 """
+APP_NAME = version.name
+APP_VERSION = version.__version__
 
 
-# TODO color
 # TODO Command line interaction
-# TODO phone
 
 class Dict_tiny(cli.Application):
-    PROGNAME = "Dict-tiny"
-    VERSION = "0.2.1"
-    DESCRIPTION = "A tiny command-line dictionary that scrapes youdao.com. Just for fun."
+    PROGNAME = colors.green | APP_NAME
+    VERSION = colors.yellow | APP_VERSION
+    DESCRIPTION = version.DESCRIPTION
 
     moredetail = cli.Flag(["-m", "--more"],
                           help="If given, more detail translation will be shown. You need to give a word or -c.")
@@ -44,18 +46,30 @@ class Dict_tiny(cli.Application):
         English_Chinese
         """
 
-        data = self.downloader(word)
+        count = 2
+        data, status_code = self.downloader(word)
+        if data is None:  # no internet
+            return
+        phone = data.xpath('.//div[@id="phrsListTab"]/h2//span[@class="pronounce"]//text()')
         content = data.xpath('.//div[@id="phrsListTab"]/div[@class="trans-container"]/ul/li//text()')
-        print(word)
-        for i in range(len(word) - 1):
-            print("=", end="")
-        print("==")
+        print(colors.green | word, end='  ')
+        for each_phone in phone:
+            if each_phone:
+                print(colors.green | each_phone.strip(), end="")
+                count += len(each_phone.strip())
+        print("\n", end="")
+        for i in range(len(word) - 1 + count):
+            print(colors.green | "=", end="")
+        print(colors.green | "==")
         if len(content) >= 1:
             for each_result in content:
                 print(each_result)
             self.targetWord = word + "_en"
         else:
-            print("The translation of this word cannot be found at this time. Please try again.")
+            if status_code == 200:  # no translation
+                print(colors.yellow | "Did not find an explanation for this word.")
+            else:  # 403?
+                print(colors.yellow | "The translation of this word cannot be found at this time. Please try again.")
         return
 
     def show_more(self, word, type, row=3, printall=True):
@@ -65,9 +79,10 @@ class Dict_tiny(cli.Application):
 
         data_base = get_data(word)
         if not data_base:
-            print("The detail translation of this word cannot be found at this time. Please try again later.")
+            print(
+                colors.yellow | "The detail translation of this word cannot be found at this time. Please try again later.")
             return
-            # print_basetrans(data_base)
+        # print_basetrans(data_base)
         print_detailtrans(data_base, type, row, printall)  # two parameters：row=3, printall=False
         # print("[Error!] Cannot get detail translation.")
         return
@@ -77,7 +92,11 @@ class Dict_tiny(cli.Application):
         Chinese_English
         """
 
-        data = self.downloader(word)
+        count = 2
+        data, status_code = self.downloader(word)
+        if data is None:  # no internet
+            return
+        phone = data.xpath('.//div[@id="phrsListTab"]/h2/span[@class="phonetic"]//text()')
         content = data.xpath('.//div[@id="phrsListTab"]/div[@class="trans-container"]/ul//span//text()')
         for i in range(len(content)):
             if "\n" in content[i]:
@@ -87,14 +106,22 @@ class Dict_tiny(cli.Application):
                 content[i - 1] = content[i + 1] = ""
         content = "".join(content[:-1])
         if content:
-            print(word)
-            for i in range(len(word) - 1):
-                print("=", end="")
-            print("==")
+            print(colors.green | word, end='  ')
+            for each_phone in phone:
+                if each_phone:
+                    print(colors.green | each_phone.strip(), end="")
+                    count += len(each_phone.strip())
+            print("\n", end="")
+            for i in range(len(word) - 1 + count):
+                print(colors.green | "=", end="")
+            print(colors.green | "==")
             print(content)
             self.targetWord = word + "_cn"
         else:
-            print("The translation of this word cannot be found at this time. Please try again.")
+            if status_code == 200:  # no translation
+                print(colors.yellow | "Did not find an explanation for this word.")
+            else:  # 403?
+                print(colors.yellow | "The translation of this word cannot be found at this time. Please try again.")
         return
 
     @cli.switch(["-c", "--clipboard"])
@@ -108,21 +135,28 @@ class Dict_tiny(cli.Application):
             clipboard_data = pyperclip.paste().strip().replace('\n', '')
         except:
             self.IS_TRANS = 1
-            print("[Error!] Cannot get clipboard content.")
+            print(colors.red | "[Error!] Cannot get clipboard content.")
             return
 
         if clipboard_data:
             self.main_(clipboard_data)
         else:
             self.IS_TRANS = 1
-            print("There is no content in the clipboard.")
+            print(colors.yellow | "There is no content in the clipboard.")
         return
 
     def downloader(self, word):
         request_url = "http://youdao.com/w/%s" % word
-        result = requests.get(request_url, headers=self.FAKE_HEADER).text
-        result_selector = html.etree.HTML(result)
-        return result_selector
+        try:
+            result = requests.get(request_url, headers=self.FAKE_HEADER)
+            result_selector = html.etree.HTML(result.text)
+            resp_code = result.status_code
+        except requests.exceptions.ConnectionError as e:
+            print(colors.red | "[Error!] Unable to download webpage.")
+            print("<%s>" % e)
+            result_selector = None
+            resp_code = None
+        return result_selector, resp_code
 
     def is_alphabet(self, word):
         is_alphabet = {
@@ -154,7 +188,7 @@ class Dict_tiny(cli.Application):
         elif self.is_alphabet(word) == 'cn':
             self.trans_cn(word)
         else:
-            print("[Error!] This is not an English word or a Chinese word.")
+            print(colors.red | "[Error!] This is not an English word or a Chinese word.")
         return
 
     def main(self, *word):
@@ -162,8 +196,8 @@ class Dict_tiny(cli.Application):
             self.help()
         elif word and not self.IS_TRANS:
             if len(word) > 1:
-                print(
-                    "Oops! You may want to translate a sentence, but I can only choose the first word as the target word.")
+                print(colors.yellow |
+                      "Oops! You may want to translate a sentence, but I can only choose the first word as the target word.")
             word = word[0]
             self.main_(word)
 
